@@ -53,7 +53,7 @@ $lang = array_merge($lang, array(
 	'SYSTEM_TIMEZONE'	=> 'Часовий пояс для гостей форуму',
 	'SYSTEM_TIMEZONE_EXPLAIN'         => 'Часовий пояс, який буде використовуватись для відображення часу для незалогованих користувачів (гостей, ботів). Залоговані користувачі встановлюють часовий пояс при реєстрації і можуть змінювати його в своїй панелі керування.',
 	'WARNINGS_EXPIRE'	=> 'Тривалість попередження',
-	'WARNINGS_EXPIRE_EXPLAIN'	=> 'Кількість днів, які повинні пройти до того, як попередження буде автоматично зняте з користувача.',
+	'WARNINGS_EXPIRE_EXPLAIN'	=> 'Кількість днів, які повинні пройти до того, як попередження буде автоматично зняте з користувача. Встановіть значення 0 для того, що зробити попередження постійними.',
 ));
 
 // Board Features
@@ -170,7 +170,7 @@ $lang = array_merge($lang, array(
 	'MAX_POST_URLS'	=> 'Максимальна кількість посилань в повідомленні',
 	'MAX_POST_URLS_EXPLAIN'	=> 'Максимальне число посилань URL в повідомленні. Встановіть 0 для необмеженої кількості.',
 	'MIN_CHAR_LIMIT' => 'Мінімальна кількість символів у повідомленні',
-	'MIN_CHAR_LIMIT_EXPLAIN' => 'Мінімальна кількість символів, яку повинен ввести користувач в повідомленні/приватному повідомленні.',
+	'MIN_CHAR_LIMIT_EXPLAIN' => 'Мінімальна кількість символів, яку повинен ввести користувач в повідомленні/приватному повідомленні. Мінімальне значення для цього налаштування - 1.',
 	'POSTING'	=> 'Повідомлень',
 	'POSTS_PER_PAGE'	=> 'Повідомлень на сторінку',
 	'QUOTE_DEPTH_LIMIT'	=> 'Максимальна кількість цитат в повідомленні',
