@@ -43,7 +43,7 @@ $lang = array_merge($lang, array(
 	'TRANSLATION_INFO'	=> 'Український переклад &copy 2005-2011 <a class="copyright" target="_blank" href="http://phpbb.com.ua/">Українська підтримка phpBB</a>',
 	'DIRECTION'	=> 'ltr',
 	'DATE_FORMAT'	=> '|d M Y|',
-	'USER_LANG'	=> 'uk-ua',
+	'USER_LANG'	=> 'uk',
 
 	'1_DAY'	=> '1 день',
 	'1_MONTH'	=> '1 місяць',
@@ -166,13 +166,15 @@ $lang = array_merge($lang, array(
 	'EMPTY_MESSAGE_SUBJECT'	=> 'Ви повинні вказати тему при створенні нового повідомлення.',
 	'ENABLED'	=> 'Увімкнено',
 	'ENCLOSURE'	=> 'Обмежувач',
+	'ENTER_USERNAME'					=> 'Введіть ім\'я користувача',
+
 	'ERR_JAB_AUTH'						=> 'Не вдалось авторизуватись на сервері Jabber.',
 	'ERR_JAB_CONNECT'					=> 'Не вдалось під\'єднатись до сервера Jabber.',
 	'ERR_CHANGING_DIRECTORY'	=> 'Невдалось змінити директорію.',
 	'ERR_CONNECTING_SERVER'	=> 'Помилка підключення до сервера.',
 	'ERR_UNABLE_TO_LOGIN'	=> 'Вказані вами ім\'я користувача або пароль невірні.',
-   	'ERR_UNWATCHING'               => 'Сталася помилка при спробі скасувати підписку.',
-   	'ERR_WATCHING'                  => 'Сталася помилка при спробі оформити підписку.',
+  'ERR_UNWATCHING'               => 'Сталася помилка при спробі скасувати підписку.',
+  'ERR_WATCHING'                  => 'Сталася помилка при спробі оформити підписку.',
 	'ERR_WRONG_PATH_TO_PHPBB'	=> 'Заданий шлях до phpBB невірний.',
 	'EXPAND_VIEW'	=> 'Розгорнутий вигляд',
 	'EXTENSION'	=> 'Розширення',
@@ -200,6 +202,8 @@ $lang = array_merge($lang, array(
 	'FORUM_RULES_LINK'	=> 'Натисніть тут для перегляду правил форуму',
 	'FROM'	=> 'з',
 	'FSOCK_DISABLED'	=> 'Ця операція не може бути виконана, тому що функцію <var>fsockopen</var> вимкнено або сервер недоступний.',
+	'FSOCK_TIMEOUT'			=> 'Виникла помилка під час читання потоку даних з мережі.',
+
 	'FTP_FSOCK_HOST'	=> 'FTP-сервер',
 	'FTP_FSOCK_HOST_EXPLAIN'	=> 'FTP-сервер для з\'єднання з вашим сайтом.',
 	'FTP_FSOCK_PASSWORD'	=> 'Пароль FTP',
@@ -247,7 +251,7 @@ $lang = array_merge($lang, array(
 	'G_REGISTERED'	=> 'Зареєстровані користувачі',
 	'G_REGISTERED_COPPA'	=> 'Зареєстровані COPPA користувачі',
 	'G_GLOBAL_MODERATORS'	=> 'Супермодератори',
- 	'G_NEWLY_REGISTERED'		=> 'Нові користувачі',
+	'G_NEWLY_REGISTERED'		=> 'Нові користувачі',
 	'HIDDEN_USERS_ONLINE'	=> '%d прихованих користувачів',
 	'HIDDEN_USERS_TOTAL'	=> '%d прихованих',
 	'HIDDEN_USERS_TOTAL_AND'      => '%d прихованих і ',
@@ -375,8 +379,8 @@ $lang = array_merge($lang, array(
 	'NO_ONLINE_USERS'	=> 'Немає зареєстрованих користувачів',
 	'NO_POSTS'	=> 'Немає повідомлень',
 	'NO_POSTS_TIME_FRAME'	=> 'За обраний період часу немає повідомлень.',
- 	'NO_FEED_ENABLED' => 'Канали новин недоступні на цьому форумі.',
- 	'NO_FEED' => 'Заданий канал новин недоступний.',
+  'NO_FEED_ENABLED' => 'Канали новин недоступні на цьому форумі.',
+  'NO_FEED' => 'Заданий канал новин недоступний.',
 	'NO_SUBJECT'	=> 'Тему не задано',
 	'NO_SUCH_SEARCH_MODULE'	=> 'За заданими критеріями нічого не знайдено.',
 	'NO_SUPPORTED_AUTH_METHODS'	=> 'Метод автентифікації не підтримується.',
@@ -408,10 +412,10 @@ $lang = array_merge($lang, array(
 	'OPTIONS'	=> 'Налаштування',
 	'PAGE_OF'	=> 'Сторінка <strong>%1$d</strong> з <strong>%2$d</strong>',
 	'PASSWORD'	=> 'Пароль',
- 	'PIXEL'		=> 'пікс.',
+  'PIXEL'		=> 'пікс.',
 	'PLAY_QUICKTIME_FILE'	=> 'Програти файл QuickTime',
 	'PM'	=> 'ПП',
-        'PM_REPORTED'         => 'Натисніть для перегляду звіту',
+  'PM_REPORTED'         => 'Натисніть для перегляду звіту',
 	'POSTING_MESSAGE'	=> 'Розміщення повідомлення в %s',
 	'POSTING_PRIVATE_MESSAGE'	=> 'Пише приватне повідомлення',
 	'POST'	=> 'Повідомлення',
@@ -478,10 +482,10 @@ $lang = array_merge($lang, array(
 	'RETURN_PAGE'	=> '%sНа попередню сторінку%s',
 	'RETURN_TOPIC'	=> '%sПовернутись до теми%s',
 	'RETURN_TO'	=> 'Повернутись до',
- 	'FEED' => 'Канал',
- 	'FEED_NEWS' => 'Новини',
- 	'FEED_TOPICS_ACTIVE'		=> 'Активні теми',
- 	'FEED_TOPICS_NEW'			=> 'Нові теми',
+  'FEED' => 'Канал',
+  'FEED_NEWS' => 'Новини',
+  'FEED_TOPICS_ACTIVE'		=> 'Активні теми',
+  'FEED_TOPICS_NEW'			=> 'Нові теми',
 	'RULES_ATTACH_CAN'	=> 'Ви <strong>можете</strong> додавати файли у цьому форумі',
 	'RULES_ATTACH_CANNOT'	=> 'Ви <strong>не можете</strong> додавати файли у цьому форумі',
 	'RULES_DELETE_CAN'	=> 'Ви <strong>можете</strong> видаляти ваші повідомлення у цьому форумі',
@@ -512,7 +516,7 @@ $lang = array_merge($lang, array(
 	'SEARCH_SELF'	=> 'Ваші повідомлення',
 	'SEARCH_TOPIC'	=> 'Пошук в темі',
 	'SEARCH_UNANSWERED'	=> 'Теми без відповідей',
-   'SEARCH_UNREAD' => 'Непрочитані повідомлення',
+  'SEARCH_UNREAD' => 'Непрочитані повідомлення',
   'SEARCH_USER_POSTS'			=> 'Знайти повідомлення користувача',
 	'SECONDS'	=> 'Секунд',
 	'SELECT'	=> 'Вибрати',
@@ -531,7 +535,7 @@ $lang = array_merge($lang, array(
 	'SORT_JOINED'	=> 'З нами з',
 	'SORT_LOCATION'	=> 'Звідки',
 	'SORT_RANK'	=> 'Статус',
- 	'SORT_POSTS' => 'Повідомлення',
+  'SORT_POSTS' => 'Повідомлення',
 	'SORT_TOPIC_TITLE'	=> 'Назва теми',
 	'SORT_USERNAME'	=> 'Ім\'я користувача',
 	'SPLIT_TOPIC'	=> 'Розділити тему',
@@ -549,7 +553,7 @@ $lang = array_merge($lang, array(
 	'TEST_CONNECTION'	=> 'Перевірити з\'єднання',
 	'THE_TEAM'	=> 'Команда',
 	'TIME'	=> 'Час',
-   	'TOO_LARGE'                  => 'Значення, яке ви ввели є занадто великим.',
+  'TOO_LARGE'                  => 'Значення, яке ви ввели є занадто великим.',
 	'TOO_LARGE_MAX_RECIPIENTS'      => 'Введене вами значення налаштування <strong>Максимально дозволена кількість одержувачів приватного повідомлення</strong> є занадто великим.',
 	'TOO_LONG'                  => 'Введене вами значення занадто довге.',
 	'TOO_LONG_AIM'	=> 'Введене вами ім\'я AIM надто довге.',
@@ -569,7 +573,7 @@ $lang = array_merge($lang, array(
 	'TOO_LONG_WEBSITE'	=> 'Введена вами адреса вебсайту надто довга.',
 	'TOO_LONG_YIM'	=> 'Введене вами ім\'я Yahoo Messenger надто довге.',
 	'TOO_SMALL'                  => 'Значення, яке ви ввели є занадто малим.',
-        'TOO_SMALL_MAX_RECIPIENTS'      => 'Введене вами значення налаштування <strong>Максимально дозволена кількість одержувачів приватного повідомлення</strong> є занадто малим.',
+  'TOO_SMALL_MAX_RECIPIENTS'      => 'Введене вами значення налаштування <strong>Максимально дозволена кількість одержувачів приватного повідомлення</strong> є занадто малим.',
 	'TOO_MANY_VOTE_OPTIONS'	=> 'Ви вибрали надто багато варіантів при голосуванні.',
 	'TOO_SHORT'                  => 'Введене вами значення занадто коротке.',
 	'TOO_SHORT_AIM'	=> 'Введене вами ім\'я AIM надто коротке.',
@@ -590,7 +594,7 @@ $lang = array_merge($lang, array(
 	'TOO_SHORT_YIM'	=> 'Введене вами ім\'я Yahoo Messenger надто коротке.',
 	'TOPIC'	=> 'Тема',
 	'TOPICS'	=> 'Теми',
- 	'TOPICS_UNAPPROVED' => 'Принаймні одну тему в цьому форумі не було схвалено.',
+	'TOPICS_UNAPPROVED' => 'Принаймні одну тему в цьому форумі не було схвалено.',
 	'TOPIC_ICON'	=> 'Значок теми',
 	'TOPIC_LOCKED'	=> 'Ця тема закрита, ви не можете редагувати повідомлення і писати відповіді',
 	'TOPIC_LOCKED_SHORT' => 'Тему закрито',
@@ -622,7 +626,11 @@ $lang = array_merge($lang, array(
 	'UNREAD_PMS'	=> '<strong>%d</strong> непрочитаних повідомлень',
 	'UNREAD_POST'         => 'Непрочитане повідомлення',
 	'UNREAD_POSTS'         => 'Непрочитані повідомлення',
-	'UNWATCHED_FORUMS'	=> 'Відтепер ви не слідкуєте за вибраними форумами.',
+	'UNWATCH_FORUM_CONFIRM'		=> 'Ви впевнені, що бажаєте відписатись від цього форуму?',
+	'UNWATCH_FORUM_DETAILED'	=> 'Ви впевнені, що бажаєте відписатись від форуму “%s”?',
+	'UNWATCH_TOPIC_CONFIRM'		=> 'Ви впевнені, що бажаєте відписатись від цієї теми?',
+	'UNWATCH_TOPIC_DETAILED'	=> 'Ви впевнені, що бажаєте відписатись від теми “%s”?',
+  'UNWATCHED_FORUMS'	=> 'Відтепер ви не слідкуєте за вибраними форумами.',
 	'UNWATCHED_TOPICS'	=> 'Відтепер ви не слідкуєте за вибраними темами.',
 	'UPDATE'	=> 'Оновити',
 	'UPLOAD_IN_PROGRESS'	=> 'Відбувається завантаження.',
@@ -636,7 +644,7 @@ $lang = array_merge($lang, array(
 	'USER_POSTS'	=> '%d повідомлень',
 	'USERS'	=> 'Користувачі',
 	'USE_PERMISSIONS'	=> 'Перевірити права користувачів.',
- 	'USER_NEW_PERMISSION_DISALLOWED' => 'Вам не дозволено використовувати цю можливість. Можливо, ви недавно зареєструвались на форумі, або вам необхідно проявити більше активності, щоб отримати можливість її використання.',
+	'USER_NEW_PERMISSION_DISALLOWED' => 'Вам не дозволено використовувати цю можливість. Можливо, ви недавно зареєструвались на форумі, або вам необхідно проявити більше активності, щоб отримати можливість її використання.',
 	'VARIANT_DATE_SEPARATOR'	=> ' / ',
 	'VIEWED'	=> 'Переглянуто',
 	'VIEWING_FAQ'	=> 'Переглядає FAQ',
@@ -666,6 +674,10 @@ $lang = array_merge($lang, array(
 	'VISIT_WEBSITE'	=> 'Відвідати вебсайт',
 	'WARNINGS'	=> 'Попередження',
 	'WARN_USER'	=> 'Зробити попередження',
+  'WATCH_FORUM_CONFIRM'	=> 'Ви впевнені, що бажаєте підписатись на цей форум?',
+	'WATCH_FORUM_DETAILED'	=> 'Ви впевнені, що бажаєте підписатись на форум “%s”?',
+	'WATCH_TOPIC_CONFIRM'	=> 'Ви впевнені, що бажаєте підписатись на цю тему?',
+	'WATCH_TOPIC_DETAILED'	=> 'Ви впевнені, що бажаєте підписатись на тему “%s”?',
 	'WELCOME_SUBJECT'	=> 'Ласкаво просимо на %s форум',
 	'WEBSITE'	=> 'Вебсайт',
 	'WHOIS'	=> 'Whois',
@@ -696,10 +708,10 @@ $lang = array_merge($lang, array(
 	'SEND_EMAIL_USER'	=> 'Надіслати е-mail користувачу',
 
 	'datetime'	=> array(
-		'TODAY'	=> 'Сьогодні',
-		'TOMORROW'	=> 'Завтра',
-		'YESTERDAY'	=> 'Вчора',
-		'AGO'		=> array(
+	'TODAY'	=> 'Сьогодні',
+	'TOMORROW'	=> 'Завтра',
+	'YESTERDAY'	=> 'Вчора',
+	'AGO'		=> array(
 			0		=> 'менше хвилини тому',
 			1		=> '%d хвилини тому',
 			2		=> '%d хвилин тому',
