@@ -60,7 +60,7 @@ $help = array(
 	),
 	array(
 		0 => 'Я колись зареєструвався, але тепер не можу увійти на форум?!',
-		1 => 'Спробуйте знайти лист e-mail, який ви отримали під час реєстрації, перевірити ваші ім\'я користувача та пароль та повторити вашу спробу. Можливо, що адміністратор з якихось причин деактивував або видалив ваш обліковий запис. До того ж, на багатьох форумах адміністратори періодично видаляють користувачів, які не писали повідомлень протягом тривалого часу, з метою зменшення розміру бази даних. Якщо це трапилось, спробуйте ще раз зареєструватись і прийняти участь у дискусіях.'
+		1 => 'Можливо адміністратор з якихось причин видалив або вимкнув ваш обліковий запис. На багатьох форумах для зменшення розміру бази даних періодично видаляються облікові записи користувачів, які протягом довгого часу не створювали повідомлень. Якщо так сталось, спробуйте повторно зареєструватись і прийняти участь у дискусіях.'
 	),
 	array(
 		0 => 'Що таке COPPA?',
