@@ -55,21 +55,21 @@ $lang = array_merge($lang, array(
 	'ALREADY_DELETED'	=> 'Це повідомлення вже видалене.',
 	'ATTACH_QUOTA_REACHED'	=> 'Досягнуто максимально допустимий розмір приєднаних файлів.',
 	'ATTACH_SIG'	=> 'Приєднати підпис (підписи можна змінювати в панелі керування)',
-	'BBCODE_B_HELP'	=> 'Жирний текст: [b]текст[/b]  (alt+b)',
-	'BBCODE_C_HELP'	=> 'Код: [code]код[/code]  (alt+c)',
-	'BBCODE_E_HELP'	=> 'Список: Додає елемент списку',
-	'BBCODE_F_HELP'	=> 'Розмір шрифту: [size=85]маленький текст[/size]',
-	'BBCODE_IS_OFF'	=> '%sBBCode%s <em>вимкнено</em>',
+	'BBCODE_B_HELP' => 'Жирний текст: [b]текст[/b]  (alt+b)',
+	'BBCODE_C_HELP' => 'Код: [code]код[/code]  (alt+c)',
+  'BBCODE_D_HELP'  => 'Флеш: [flash=ширина,висота]http://url[/flash]',
+	'BBCODE_F_HELP' => 'Розмір шрифту: [size=85]маленький текст[/size]',
+	'BBCODE_IS_OFF' => '%sBBCode%s <em>вимкнено</em>',
 	'BBCODE_IS_ON'	=> '%sBBCode%s <em>увімкнено</em>',
-	'BBCODE_I_HELP'	=> 'Курсивний текст: [i]текст[/i]  (alt+i)',
-	'BBCODE_L_HELP'	=> 'Список: [list]текст[/list]  (alt+l)',
-	'BBCODE_O_HELP'	=> 'Впорядкований список: [list=]текст[/list]  (alt+o)',
-	'BBCODE_P_HELP'	=> 'Вставити зображення: [img]http://url_зображення[/img]  (alt+p)',
-	'BBCODE_Q_HELP'	=> 'Цитата: [quote]текст[/quote]  (alt+q)',
-	'BBCODE_S_HELP'	=> 'Колір шрифту: [color=red]текст[/color]  Порада: ви можете також використовувати конструкцію color=#FF0000',
-	'BBCODE_U_HELP'	=> 'Підкреслений текст: [u]текст[/u]  (alt+u)',
-	'BBCODE_W_HELP'	=> 'Вставити URL: [url]http://url[/url] чи [url=http://url]URL text[/url]  (alt+w)',
-	'BBCODE_D_HELP'	=> 'Флеш: [flash=ширина,висота]http://url[/flash]  (alt+d)',
+	'BBCODE_I_HELP'  => 'Курсивний текст: [i]текст[/i]  (alt+i)',
+	'BBCODE_L_HELP'  => 'Список: [list]текст[/list]  (alt+l)',
+	'BBCODE_O_HELP'  => 'Впорядкований список: [list=]текст[/list]  (alt+o)',
+	'BBCODE_P_HELP'  => 'Вставити зображення: [img]http://url_зображення[/img]  (alt+p)',
+	'BBCODE_Q_HELP'  => 'Цитата: [quote]текст[/quote]  (alt+q)',
+	'BBCODE_S_HELP'  => 'Колір шрифту: [color=red]текст[/color]  Порада: ви можете також використовувати конструкцію color=#FF0000',
+	'BBCODE_U_HELP'  => 'Підкреслений текст: [u]текст[/u]  (alt+u)',
+	'BBCODE_W_HELP'  => 'Вставити URL: [url]http://url[/url] чи [url=http://url]URL text[/url]  (alt+w)',
+	'BBCODE_Y_HELP' => 'Список: Додає елемент списку',
 	'BUMP_ERROR'	=> 'Ви не можете піднімати цю тему відразу після останнього повідомлення.',
 	'CANNOT_DELETE_REPLIED'	=> 'Вибачте, але ви можете видаляти лише ті повідомлення, на які ще надійшли відповіді.',
 	'CANNOT_EDIT_POST_LOCKED'	=> 'Це повідомлення заблоковане. Ви більше не можете редагувати це повідомлення.',
