@@ -139,6 +139,7 @@ $lang = array_merge($lang, array(
 	'CURRENT_IMAGE'	=> 'Поточне зображення',
 	'CURRENT_PASSWORD'	=> 'Поточний пароль',
 	'CURRENT_PASSWORD_EXPLAIN'	=> 'Вам необхідно ввести ваш поточний пароль, якщо ви бажаєте змінити ваше ім\'я користувача, адресу e-mail чи пароль.',
+	'CUR_PASSWORD_EMPTY'		=> 'Ви не ввели свій поточний пароль.',
 	'CUR_PASSWORD_ERROR'	=> 'Пароль, введений вами, не співпадає з поточним паролем.',
 	'CUSTOM_DATEFORMAT'	=> 'Інший…',
 	'DEFAULT_ACTION'	=> 'Дії за замовчуванням',
@@ -256,9 +257,11 @@ $lang = array_merge($lang, array(
 	'MOVE_PM_ERROR'	=> 'Під час переміщення повідомлень до нової папки сталася помилка, лише %1d з %2d повідомлень було переміщено.',
 	'MOVE_TO_FOLDER'	=> 'Перемістити в папку',
 	'MOVE_UP'	=> 'Підняти доверху',
+  'NEW_EMAIL_CONFIRM_EMPTY'		=> 'Ви не ввели підтвердження адреси e-mail.',
 	'NEW_EMAIL_ERROR'	=> 'Введені вами адреси email не співпадають.',
 	'NEW_FOLDER_NAME'	=> 'Нове ім\'я папки',
 	'NEW_PASSWORD'	=> 'Новий пароль',
+  'NEW_PASSWORD_CONFIRM_EMPTY'	=> 'Ви не ввели пароль підтвердження.',
 	'NEW_PASSWORD_ERROR'	=> 'Введені вами паролі не співпадають.',
 	'NOTIFY_METHOD'	=> 'Спосіб повідомлення',
 	'NOTIFY_METHOD_BOTH'	=> 'Обидва',
